==> open-xchange-usm_7.4.2.orig.tar.bz2: open-xchange-usm-7.4.2/com.openexchange.usm.api/src/com/openexchange/usm/api/datatypes/PIMAttachmentsDataType.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.usm.api.datatypes;

import java.io.Serializable;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;
import com.openexchange.usm.api.session.Session;

/**
 * DataType for attachments to OX PIM objects
 * 
 * @author afe
 */
public class PIMAttachmentsDataType extends AbstractDataType<PIMAttachments> {

    private static final String NAME = "Attachments";

    public PIMAttachments checkValue(Object o) {
        if (o != null && !(o instanceof PIMAttachments))
            generateTypeError(o);
        return (PIMAttachments) o;
    }

    public void addToJSONArray(Session session, JSONArray parent, Object value) throws JSONException {
        parent.put((value == null) ? JSONObject.NULL : ((PIMAttachments) value).getTimestamp());
    }

    public PIMAttachments extractFromJSONArray(Session session, JSONArray array, int index) throws JSONException {
        return (array.isNull(index) || array.getLong(index) == 0) ? null : new PIMAttachments(array.getLong(index));
    }

    public void storeInJSONObject(Session session, JSONObject parent, String field, Object value) throws JSONException {
        parent.put(field, (value == null) ? JSONObject.NULL : ((PIMAttachments) value).getTimestamp());
    }

    public PIMAttachments extractFromJSONObject(Session session, JSONObject jsonObject, String field) throws JSONException {
        return (jsonObject.isNull(field) || jsonObject.getLong(field) == 0) ? null : new PIMAttachments(jsonObject.getLong(field));
    }

    public String getName() {
        return NAME;
    }

    /**
     * Override standard method to make sure that created copies of DataObjects do not have the forceModified flag set for their
     * PIMAttachments fields
     */
    @Override
    public PIMAttachments createCopy(Object source) {
        PIMAttachments v = checkValue(source);
        return (v != null && v.isForceModified()) ? new PIMAttachments(v.getTimestamp(), v.getAttachments()) : v;
    }

    @Override
    public Serializable serialize(Object value) {
        return (value instanceof PIMAttachments) ? new SerializedPIMAttachments((PIMAttachments) value) : null;
    }

    @Override
    public PIMAttachments deserialize(Serializable value) {
        if (value instanceof SerializedPIMAttachments)
            return ((SerializedPIMAttachments) value).toPIMAttachments();
        return super.deserialize(value);
    }
}

==> open-xchange-usm_7.6.1.orig.tar.bz2: open-xchange-usm-7.6.1/com.openexchange.usm.api/src/com/openexchange/usm/api/datatypes/PIMAttachmentsDataType.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.usm.api.datatypes;

import java.io.Serializable;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;
import com.openexchange.usm.api.session.Session;

/**
 * DataType for attachments to OX PIM objects
 * 
 * @author afe
 */
public class PIMAttachmentsDataType extends AbstractDataType<PIMAttachments> {

    public PIMAttachmentsDataType() {
        super("Attachments");
    }

    @Override
    public PIMAttachments checkValue(Object o) {
        if (o != null && !(o instanceof PIMAttachments))
            generateTypeError(o);
        return (PIMAttachments) o;
    }

    @Override
    public void addToJSONArray(Session session, JSONArray parent, Object value) {
        parent.put((value == null) ? JSONObject.NULL : ((PIMAttachments) value).getTimestamp());
    }

    @Override
    public PIMAttachments extractFromJSONArray(Session session, JSONArray array, int index) throws JSONException {
        return (array.isNull(index) || array.getLong(index) == 0) ? null : new PIMAttachments(array.getLong(index));
    }

    @Override
    public void storeInJSONObject(Session session, JSONObject parent, String field, Object value) throws JSONException {
        parent.put(field, (value == null) ? JSONObject.NULL : ((PIMAttachments) value).getTimestamp());
    }

    @Override
    public PIMAttachments extractFromJSONObject(Session session, JSONObject jsonObject, String field) throws JSONException {
        return (jsonObject.isNull(field) || jsonObject.getLong(field) == 0) ? null : new PIMAttachments(jsonObject.getLong(field));
    }

    /**
     * Override standard method to make sure that created copies of DataObjects do not have the forceModified flag set for their
     * PIMAttachments fields
     */
    @Override
    public PIMAttachments createCopy(Object source) {
        PIMAttachments v = checkValue(source);
        return (v != null && v.isForceModified()) ? new PIMAttachments(v.getTimestamp(), v.getAttachments()) : v;
    }

    @Override
    public Serializable serialize(Object value) {
        return (value instanceof PIMAttachments) ? new SerializedPIMAttachments((PIMAttachments) value) : null;
    }

    @Override
    public PIMAttachments deserialize(Serializable value) {
        if (value instanceof SerializedPIMAttachments)
            return ((SerializedPIMAttachments) value).toPIMAttachments();
        return super.deserialize(value);
    }
}
